==> whmcs-8.13.1-release.1.zip: crons/domainsync.php <==
<?php //ICB0 72:0 81:f49 82:11f7                                              ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.13.1 (8.13.1-release.1)                                    *
// * BuildId:4d565bc.441                                                  *
// * Build Date:02 Jun 2025                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: https://www.whmcs.com                                        *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPzJ48oO+A9W9jtQs1VzcMl1TJTF8uEAW0vN8ZzGGwlh3lw9uN/cHrb7AMpsSDpF5yo793/iI
xAnHoy3Ma2Gez9+nICe+p6Q3EuAk8Cw6UMcMneLW4Sb1P4yX7FBo/oqAGs69ysN535OOj2MGxH9Q
bbqjkxyaywNOD4ux9FXaWm5p1IDCircEp0i3OXvYMlJwKBN1q7Bxrr3wl03KQtCMBClYxLqPfOjv
iO9x0F/jiNDKDXN1yZVAhfSHpVmeKu7wIF+XnVP5GWE0L1dW795wvTnLkJJfdblku4D73Q7oHEnM
W8QDTEtACyLvbmAhSGhmVJcJCv+zcQD4D7XRCiufg5KavJ6qTVq5E416Z7q81D2XghqaASykZxC9
MA9E1mNApFjFnpAxbsiAlQxwAzBb4B2ZfzrC+NlTpNInQDRkCr4Z9exNb+Eda0evCYDNBGUU0990
C2DvmTyUnkalGk6HpbdwsG7fzk9Gq2DdIj5VfBs2gUaFhUE8TGuSbNqfIxOnGqf0lM95As19ZEB3
YZ1Qc9bYDv6JxWT1wOmztWyoGEnPVSW7O9SBXNcV5MsROXetTEvRl4WcpXakk8gI1N/BwafbvDCb
WBHnuFmnrfakLOPZL1yzwk5XaY2x1cxPf0===
HR+cPuTlA2mgpP03Gz6z3rWE30DrlpvlwoOqKhKxG8Ee6HCOucRd8OpOJy1696hFnp5/KV1D7CoP
pwVR+UHYBifkWpTJAonscgI1N01p8vOSzzVzalN88oVw0UBNNMyj1PcFNeuThfg2JfDCRzJyILfq
1nQJl4L0Slh2nghU+I5wmf9Nd8VxuHA5lLsf26uL/Rv2osHWDDwSEsgtrSuoZlloi7ex/+K1Ajs2
KHurVpX7tMgYv1aX2lVPnBqjei5/j6Fb3G69FMrNhmEaW7JWdfp0E4mCg/g97AJlOHZN81ycp8ti
tb+Nd3+Ak70mFYhWoLEjDIMj5lQErrJbw8LL9k7SpizhZmkRexzq4WYoXdc/036atsDBeh8FlWvc
QAA5t4X/ZusuomGtvLdABq1TYEvbS4DFCjcc0YMLAZraSvDB62cG8l1bgd8WygAbcUIEwevqu7Ru
+Zj0GlmOfelQ77muT9egdWEGM60BzkhhX1bBbv91c+sdIrimpuJYX+q4cCISVqa0K1atl7FA9Xpb
9D9OAJQ4ykqV9q8KZHwYadTP7ebSCNfQU/4c2nYMY/JsBwDFXsA7VT6BhDSwlwtHf71ymCbPNE82
WK3FxmZ48KuxeF3MNB1/uCFa+d+jyVyHFvIW0W/QPb5mHL7fATvk2gyX41wtANhGxW===
HR+cPzftSFoMn4Zq7ydbt/crNehWU59o7Rq52gZ89IPthNGTT0haex6AWRZ0b9p88dsaK5M5i13N
wkB4m5dwCpwxLcv4sSSmmPCnIvDreBs9rmlT4czOxGxH1Z6fSzarm0ocOGj39JlT7bT1fz4VtPh5
8tsylmhCMK1WR+6xX0ivyajUv+Fso5AIHJwZNfqG5fcbhVv6L4/eWpuCc1YPZKV1yJY/d2A9oxmC
TFEaJgRILK086nMIX0hrIQUt7Yl+CzsM23QoIKDDwvpzTxKFceh0QeeO0mo0vDrnSUfmiheB/O9O
kNbUSSzIZgNqdQgJCuPiQqx140M1hYnCzP09BWln6FbanYz+JXcD2OvWOu9PWJVaAvMk683LJAQu
ZHTOBGAo7McmbP9yodrDfwpHIzgUL1EzDBElwwnqW6Z4wrotpP3rmULuTrIjsdg5PdQF9P7pzBx/
QbFFlvpWx9pPE1uKnhEvn0HlYhdjQqx/eoHLVgGT87CYXw3NOWpuJIuoO8+uPyo7dzotJ/KkCsLG
T5yZWt82Nu1M3ztaDZkzU0cZa45DOZ8HQ7WIaCFh++IFqK3n3882ub12/u1m0t8mqRsxhj5XuDRF
tNInLvtAnEGOxrBjaeozEpvUO5kL/aZPH84XdXvlRSzV1A27qUOLnpRhTvMfghc1e7G=

==> whmcs-9.0.1-release.1.zip: crons/domainsync.php <==
<?php //ICB0 82:0 83:f64                                                      ?><?php //00cba
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version: 9.0.1 (9.0.1-release.1)                                      *
// * BuildId: 81d80f82cb.790                                               *
// * Build Date: 05 Feb 2026                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPoeUuBsFuTYo9gnrdksH1gm7U9pjwtBbuj6yxWCH4vy2cpORCGMrvjEY1fHGoLUMML6zoZhc
02U4bWuxFjJLe1T9DEpaC92laHazHW0cGVEfNs4VqxYS5ac2NRQhTqG+CN15AG8F/rIcOUxsd1ba
fKqqXR3n7Lt9P+mu3RLghj65NmTeLxUTEff/dElW+Hj/BhYPMXTSc4IA60gm1vzdbkdPwQMoe1SL
0F4J+AzGrfj+7DnSk57ouJzPV5zTCCIFjEeds5rnltDhwk3lg9Hu7y3dk7rEY92I2vVJQbsUbtVn
uXy1TN1q7YC67RUKDgzAI8WjKmZqMj6twQ0qqv6J9TQZ6s2uCNIK8rwxc+wr7N2AhHSF6BkQ8ujM
NAV+fE81b532/vrf90Kdchk8Le8eEfNRpbIyho1XVI3fBQXFmQeYP0W3jqZb8WGgzcgTtN6Z64du
X+0I07VNbxCffZu1IgOqiXWSwcqxH1PVmQFslEwTNIlYCxK28ubs8d47+Gmdqdga+oKIy/7ScYDL
PE2fh1Q7svaxFtCe22qOtfisp7LO5duNIJcLL2kKRehRoR9GaPmjK6Xz3vRnuV+4dZl8FVXY4fQ2
jlluu6/mqOj0wY84J/91ObsccGefE1WtG/9/JSdK4io+B1ownRnmTV/AXW===
HR+cPpTWnwdsi3kE/rpUKefXfHoAkwSDr/AkojQER8DwrHLwFm7SNc1ItfLstzpL9dRurz2i/KbB
FPfxo1bp1tiZQuZyDoYZ5COm0JUC+dkoNBZWhrl4K06rnAD2qzK+yfUpRbpimNH83RDY+YisgdSx
czqrTKRnMAQmxLXQ3IHO6dM0kyRxuTOcUzwpYJ8dYqEKb0ysk76qtWmK3CrM9GJE7JfOAprHY42Z
bFG8czQgIddwL5Ft4JUH2Ch84BYkUiYcy+zFPnbtXnu52FUPAMp4h3KRlFy6y1nby5SgAYU7OIt6
ptUwPu7tSRqXRBvdpGDAX45D40hC8lN1Y9ny16N1M0vas93XAT7duJ8jowOLWFxM5XkozLgk/RrC
GXIBd5H14hAq6QsTlvEg6etF5IotAGZSiV0NYUekIReIJy4ZO3BL8MtimYV1pvFgcglJeqKZO/4T
YK8ak4PUnQrhYqCo1fFOfloksH3Qn+p5iOHuKURKsf3GJmD66bQmJ4YD4KeLimcwYB+LMPsI/VkN
xy7hxTBofsxeicirewuFAgEzTlI+EV7NO+UAYiy9v8dbNbBVVoy9OdTiHkscGifUccxopwkGvxJA
5osGFVIaqolh3I5SyG52CCaPMYmDaKtO8nGM93Q5EZKkTDfxXiGhCwWWVl0p
